==> alfresco-repository-23.2.8.1-sources.jar: org/alfresco/repo/virtual/ref/Stringifier.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.virtual.ref;

import java.io.Serializable;
import java.util.List;

/**
 * A {@link Reference} abstract tree visitor designed to produce custom string
 * representations.
 * 
 * @author Bogdan Horje
 */
public interface Stringifier extends Serializable
{
    String stringify(Reference reference) throws ReferenceEncodingException;

    String stringify(Resource resource) throws ReferenceEncodingException;

    String stringifyResource(Resource resource) throws ReferenceEncodingException;

    String stringifyResource(RepositoryResource resource) throws ReferenceEncodingException;

    String stringifyResource(ClasspathResource resource) throws ReferenceEncodingException;

    String stringify(RepositoryLocation repositoryLocation) throws ReferenceEncodingException;

    String stringifyRepositoryLocation(RepositoryLocation repositoryLocation) throws ReferenceEncodingException;

    String stringifyRepositoryLocation(RepositoryNodeRef repositoryNodeRef) throws ReferenceEncodingException;

    String stringifyRepositoryLocation(RepositoryPath repositoryPath) throws ReferenceEncodingException;

    String stringify(List<Parameter> parameters) throws ReferenceEncodingException;

    String stringify(Parameter parameter) throws ReferenceEncodingException;

    String stringifyParameter(Parameter parameter) throws ReferenceEncodingException;

    String stringifyParameter(ResourceParameter resourceParameter) throws ReferenceEncodingException;

    String stringifyParameter(StringParameter stringParameter) throws ReferenceEncodingException;

    String stringifyParameter(ReferenceParameter referenceParameter) throws ReferenceEncodingException;
}

==> alfresco-repository-25.3.0.43-sources.jar: org/alfresco/repo/virtual/ref/Stringifier.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.repo.virtual.ref;

import java.io.Serializable;
import java.util.List;

/**
 * A {@link Reference} abstract tree visitor designed to produce custom string representations.
 * 
 * @author Bogdan Horje
 */
public interface Stringifier extends Serializable
{
    String stringify(Reference reference) throws ReferenceEncodingException;

    String stringify(Resource resource) throws ReferenceEncodingException;

    String stringifyResource(Resource resource) throws ReferenceEncodingException;

    String stringifyResource(RepositoryResource resource) throws ReferenceEncodingException;

    String stringifyResource(ClasspathResource resource) throws ReferenceEncodingException;

    String stringify(RepositoryLocation repositoryLocation) throws ReferenceEncodingException;

    String stringifyRepositoryLocation(RepositoryLocation repositoryLocation) throws ReferenceEncodingException;

    String stringifyRepositoryLocation(RepositoryNodeRef repositoryNodeRef) throws ReferenceEncodingException;

    String stringifyRepositoryLocation(RepositoryPath repositoryPath) throws ReferenceEncodingException;

    String stringify(List<Parameter> parameters) throws ReferenceEncodingException;

    String stringify(Parameter parameter) throws ReferenceEncodingException;

    String stringifyParameter(Parameter parameter) throws ReferenceEncodingException;

    String stringifyParameter(ResourceParameter resourceParameter) throws ReferenceEncodingException;

    String stringifyParameter(StringParameter stringParameter) throws ReferenceEncodingException;

    String stringifyParameter(ReferenceParameter referenceParameter) throws ReferenceEncodingException;
}
